@@ -142,6 +142,10 @@ WORKSPACE_DIAGNOSTIC      =
 'Diagnosing workspace'
 WORKSPACE_SKIP_HUGE_FILE  =
 'For performance reasons, the parsing of this file has been stopped: {}'
+WORKSPACE_NOT_ALLOWED     =
+'Your workspace is set to `{}`. Lua language server refused to load this directory. Please check your configuration.[learn more here](https://github.com/sumneko/lua-language-server/wiki/Why-scanning-home-folder)'
+WORKSPACE_SCAN_TOO_MUCH   =
+'More than {} files have been scanned. The current scanned directory is `{}`. Please confirm whether the configuration is correct.'
 
 PARSER_CRASH            =
 'Parser crashed! Last words:{}'
@@ -380,6 +384,8 @@ ACTION_DISABLE_DIAG_FILE=
 'Disable diagnostics in this file ({}).'
 ACTION_MARK_ASYNC       =
 'Mark current function as async.'
+ACTION_ADD_DICT         =
+'Add \'{}\' to workspace dict'
 
 COMMAND_DISABLE_DIAG       =
 'Disable diagnostics'
@@ -399,6 +405,8 @@ COMMAND_JSON_TO_LUA        =
 'Convert JSON to Lua'
 COMMAND_JSON_TO_LUA_FAILED =
 'Convert JSON to Lua failed: {}'
+COMMAND_ADD_DICT           =
+'Add Word to dictionary'
 
 COMPLETION_IMPORT_FROM           =
 'Import from {}'
